==> dde-launchpad_1.99.11.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Mở</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Đặt tại đầu</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Di chuyển lên đầu</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Loại bỏ khỏi yêu thích</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Thêm vào yêu thích</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Loại bỏ khỏi bàn làm việc</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Gửi đến bàn làm việc</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Loại bỏ khỏi két ứng dụng</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Gửi đến két ứng dụng</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Loại bỏ khỏi khởi động</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Thêm vào khởi động</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Sử dụng proxy</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Tắt tỷ lệ hiển thị</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Gỡ cài đặt</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="33"/>
        <source>Power</source>
        <translation>Năng lượng</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="62"/>
        <source>Search</source>
        <translation>Tìm kiếm</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="109"/>
        <source>Full-screen Mode</source>
        <translation>Chế độ toàn màn hình</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Cài đặt</translation>
    </message>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Loại bỏ</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Thông dụng</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="163"/>
        <source>Window Mode</source>
        <translation>Chế độ cửa sổ</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Nhạc</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Phim</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Thiết kế đồ họa</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="32"/>
        <source>Games</source>
        <translation>Trò chơi</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Công việc văn phòng</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Đọc sách</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Phát triển</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Hệ thống</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Khác</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="400"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Bạn có chắc chắn muốn gỡ cài đặt %1?</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="412"/>
        <source>Cancel</source>
        <translation>Hủy bỏ</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="426"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Đã cài đặt gần đây</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Tất cả ứng dụng</translation>
    </message>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="556"/>
        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Không có kết quả tìm kiếm</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Sắp xếp tự do</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Sắp xếp theo danh mục</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Sắp xếp theo tên</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Chế độ sắp xếp</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Máy tính</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Hình ảnh</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Tài liệu</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Bàn làm việc</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Trung tâm điều khiển</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <location filename="../package/launcheritem.qml" line="111"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="113"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="115"/>
        <source>Music</source>
        <translation>Âm nhạc</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="117"/>
        <source>Video</source>
        <translation>Phim</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="119"/>
        <source>Graphics</source>
        <translation>Hình ảnh</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="121"/>
        <source>Games</source>
        <translation>Trò chơi</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="123"/>
        <source>Office</source>
        <translation>Hành chính</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="125"/>
        <source>Reading</source>
        <translation>Đọc</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="127"/>
        <source>Development</source>
        <translation>Phát triển</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="129"/>
        <source>System</source>
        <translation>Hệ thống</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="131"/>
        <source>Others</source>
        <translation>Khác</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="162"/>
        <source>launchpad</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="299"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Bạn có chắc muốn gỡ cài đặt %1?
</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="311"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="325"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
</context>
</TS>

==> dde-launchpad_1.99.13.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_vi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="vi">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Mở</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Đặt tại đầu</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Di chuyển lên đầu</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Loại bỏ khỏi yêu thích</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Thêm vào yêu thích</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Loại bỏ khỏi bàn làm việc</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Gửi đến bàn làm việc</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Loại bỏ khỏi két ứng dụng</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Gửi đến két ứng dụng</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Loại bỏ khỏi khởi động</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Thêm vào khởi động</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Sử dụng proxy</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Tắt tỷ lệ hiển thị</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Gỡ cài đặt</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="33"/>
        <source>Power</source>
        <translation>Năng lượng</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="62"/>
        <source>Search</source>
        <translation>Tìm kiếm</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="109"/>
        <source>Full-screen Mode</source>
        <translation>Chế độ toàn màn hình</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Cài đặt</translation>
    </message>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Loại bỏ</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Thông dụng</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="254"/>
        <source>Window Mode</source>
        <translation>Chế độ cửa sổ</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Nhạc</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Phim</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Thiết kế đồ họa</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="32"/>
        <source>Games</source>
        <translation>Trò chơi</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Công việc văn phòng</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Đọc sách</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Phát triển</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Hệ thống</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Khác</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="400"/>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="412"/>
        <source>Cancel</source>
        <translation>Hủy bỏ</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="426"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Đã cài đặt gần đây</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Tất cả ứng dụng</translation>
    </message>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="557"/>
        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Không có kết quả tìm kiếm</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Sắp xếp tự do</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Sắp xếp theo danh mục</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Sắp xếp theo tên</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Chế độ sắp xếp</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Máy tính</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Hình ảnh</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Tài liệu</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Bàn làm việc</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Trung tâm điều khiển</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <location filename="../package/launcheritem.qml" line="111"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="113"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="115"/>
        <source>Music</source>
        <translation>Âm nhạc</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="117"/>
        <source>Video</source>
        <translation>Phim</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="119"/>
        <source>Graphics</source>
        <translation>Hình ảnh</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="121"/>
        <source>Games</source>
        <translation>Trò chơi</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="123"/>
        <source>Office</source>
        <translation>Hành chính</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="125"/>
        <source>Reading</source>
        <translation>Đọc</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="127"/>
        <source>Development</source>
        <translation>Phát triển</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="129"/>
        <source>System</source>
        <translation>Hệ thống</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="131"/>
        <source>Others</source>
        <translation>Khác</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="162"/>
        <source>launchpad</source>
        <translation>Bắt đầu</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="309"/>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="321"/>
        <source>Cancel</source>
        <translation>Hủy</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="335"/>
        <source>Confirm</source>
        <translation>Xác nhận</translation>
    </message>
</context>
</TS>
